window.Gleam.initSearch([{"doc":"palabres","title":"palabres","content":"# Palabres\n\n&gt; Palabres **[\\\\pa.labʁ\\\\]** \\\n&gt; French word, coming from the Spanish word _palabra_, meaning &quot;parole&quot; &amp;\n&gt; &quot;word&quot;. \\\n&gt;\n&gt; 1. Long &amp; hard discussion to get a precise result.\n&gt; 2. An interminable and often idle discussion.\n\nPalabres is an opinionated logger, built in Gleam for Gleamlins, targetting both\nErlang and JavaScript. Palabres tries to be compatible with the most runtimes\npossible, so you can expect it to work on BEAM &amp; any flavour of\nJavaScript — with 100% compatibility while the runtime respect Node.js imports.\n\nPalabres tries to stay simple yet powerful. By using structured data, text\nmessages and potential metadata, Palabres tries to provides a nice and pleasant\nexperience out-of-the-box with few to no configuration and helps to build &amp;\nmonitor complex system.\n\n## But what does it look like?\n\nGenerally, when you&#39;re starting out a project, you rely on the default logger,\nwith its default abilities. However, in the long run, you probably want to add\ncontext, to add advance monitoring, to follow user flows, and much more, in your\nlogs. Outputting plain text in such case can make the task hard. That&#39;s where\nPalabres comes into play, it helps you to go from\n\n```sh\nINFO Server listening on http://0.0.0.0:3000\nINFO 200 GET /healthcheck\n```\n\nto\n\n```json\n{\n  &quot;level&quot;: &quot;info&quot;,\n  &quot;host&quot;: &quot;0.0.0.0&quot;,\n  &quot;id&quot;: &quot;3aa3660c-8f1f-4bbc-a530-346e140b0015&quot;,\n  &quot;message&quot;: &quot;Server started, listening&quot;,\n  &quot;port&quot;: &quot;3000&quot;,\n  &quot;scheme&quot;: &quot;http&quot;,&quot;when&quot;:&quot;2024-12-16T17:43:40Z&quot;\n}\n{\n  &quot;level&quot;: &quot;info&quot;,\n  &quot;id&quot;: &quot;c848d8f9-6c64-4d25-90dd-3ee3b14ec7a9&quot;,\n  &quot;method&quot;: &quot;GET&quot;,\n  &quot;status&quot;: &quot;404&quot;,\n  &quot;when&quot;: &quot;2024-12-16T17:43:59Z&quot;,\n  &quot;where&quot;: &quot;/&quot;\n}\n```\n\n## Installation\n\n```sh\ngleam add palabre@1\n```\n\n## Getting started\n\nTo get started, everything you need is to configure your logger, and you&#39;re\ndone! Everything remaining is to use Palabres to create logs!\n\n```gleam\nimport palabres\nimport palabres/options\nimport palabres/level\n\npub fn configure_logger() {\n  options.defaults()\n  |&gt; options.color(True)\n  |&gt; options.json(False)\n  |&gt; options.output(to: options.stdout())\n  |&gt; palabres.configure\n}\n\npub fn log_message() {\n  palabres.debug(&quot;My debug message&quot;)\n  |&gt; palabres.string(&quot;my_field&quot;, &quot;content&quot;)\n  |&gt; palabres.int(&quot;my_other_field&quot;, 12)\n  |&gt; palabres.log\n}\n```\n\nAnd you&#39;re good to go! Find the entire explanations on\n[Hexdocs](https://hexdocs.pm/palabres/palabres.html).\n","url":"index.html"},{"doc":"palabres/level","title":"Level","content":"pub type Level {\n  Emergency\n  Alert\n  Critical\n  Error\n  Warning\n  Notice\n  Info\n  Debug\n}\n Different levels of logs. Log levels correspond directly to a level of\n danger. `Emergency` is the most dangerous one, while `Debug` is the least\n dangerous one. `Info` is the default value with palabres. \\\n Once chosen, every level below the desired level are ignored.\nEmergency\n\n\nAlert\n\n\nCritical\n\n\nError\n\n\nWarning\n\n\nNotice\n\n\nInfo\n\n\nDebug\n\n\nSynonyms:\npalabres/level.Level\npalabres/level Level","url":"palabres/level.html#Level"},{"doc":"palabres/level","title":"from_string","content":"pub fn from_string(level: String) -&gt; Result(Level, Nil)\n Parse a string log level, and returns the corresponding log level. \\\n Log levels are case-insensitive, and correspond litteraly to log levels\n from `Level` type.\nSynonyms:\npalabres/level.from_string\npalabres/level from_string","url":"palabres/level.html#from_string"},{"doc":"palabres/level","title":"palabres/level","content":" Log level used by most loggers. Erlang logger uses those default log levels\n while vailla JavaScript use a subset of them. Palabres implements them all,\n whether you&#39;re running on JavaScript or Erlang. Log level will _always_\n appears in your logs, and will correctly be filtered by the logger.\n\n #### JavaScript log level equivalent\n\n Find the correspondance between log levels, and JavaScript `console`\n functions. By default, JavaScript applies some styling in browser for\n those levels. \\\n While the table can help you figure out which level to chooses, keep in\n mind it&#39;s mainly there to help you understand how to use log level, as\n palabres works differently: everything goes through `console.log` to output\n on `stdout`. When outputting to a file, logs will never go to `console`\n functions. Log level will always be indicated in the log, through\n `level=[level]` or `{ level: [level] }`, allowing for quick and easy\n indexing by a log crawler.\n\n\n\n log level | JS\n ----------|-------------------\n Emergency |\n Alert     |\n Critical  |\n Error     | `console.error`\n Warning   | `console.warning`\n Notice    |\n Info      | `console.log`\n Debug     | `console.debug`","url":"palabres/level.html"},{"doc":"palabres/options","title":"Options","content":"pub opaque type Options\n Options to configure the logger. To create with [`defaults`](#defaults).\n Below are the configurable options, usable with the corresponding functions.\n\n - [`color`](#color) Defaults to `True`. \\\n   Allow to choose if the output is colored or not.\\\n   Can be deactivated globally with the `NO_COLOR` (or `NO_COLOUR`)\n   environment variable. \\\n   Once set, `color` defaults to `False`.\n - [`json`](#json) Defaults to `False`. \\\n   Activate the JSON mode, forcing the logger to output JSON\n   instead of strings. \\\n   JSON output will automatically disable colored logging.\n - [`level`](#level) Defaults to `level.Info`. \\\n   Set the minimum required log level. \\\n   Every level below will be ignored.\n - [`output`](#output) Defaults to `stdout`. \\\n   Allow to choose writing to `stdout` or a file.\n - [`style_default_logger`](#style_default_logger) Defaults to `True`. \\\n   Apply the palabres styling to the default logger.\n\nSynonyms:\npalabres/options.Options\npalabres/options Options","url":"palabres/options.html#Options"},{"doc":"palabres/options","title":"Output","content":"pub opaque type Output\n Configurable output for the logger. Can be the standard output, or a\n selected file. \\\n Standard output can be simply selected with [`stdout`](#stdout), while file\n logging is selected with [`file`](#file). \\\n A file logger will dump the log contents at regular interval. This interval\n is configurable by using [`flush`](#flush).\n\n \n pub fn configure_logger() {\n   options.defaults()\n   // Choose to output to stdout.\n   |&gt; options.output(to: options.stdout())\n   // Choose to output to a file.\n   |&gt; options.output(to: {\n     options.file(&quot;/var/log/my_app.log&quot;)\n     // Flush interval can be seldected in milliseconds.\n     |&gt; options.flush(every: 2500)\n   })\n }\n \n\nSynonyms:\npalabres/options.Output\npalabres/options Output","url":"palabres/options.html#Output"},{"doc":"palabres/options","title":"color","content":"pub fn color(options: Options, color: Bool) -&gt; Options\n Activate or deactivate colored output. \\\n Defaults to `True` if environment variable `NO_COLOR` is unset. \\\n Defaults to `False` otherwise. \\\n If `color` is called, it takes precedence on environment variable.\nSynonyms:\npalabres/options.color\npalabres/options color","url":"palabres/options.html#color"},{"doc":"palabres/options","title":"defaults","content":"pub fn defaults() -&gt; Options\n Initialise the options with defaults.\n - `color: True` if environment variable `NO_COLOR` is unset, `False` otherwise.\n - `json: False`\n - `level: level.Info`\n - `output: stdout`\n - `style_default_logger: True`\nSynonyms:\npalabres/options.defaults\npalabres/options defaults","url":"palabres/options.html#defaults"},{"doc":"palabres/options","title":"file","content":"pub fn file(filename: String) -&gt; Output\n Creates a file output, to use with `output`. Flush interval can be configured\n with `flush`.\nSynonyms:\npalabres/options.file\npalabres/options file","url":"palabres/options.html#file"},{"doc":"palabres/options","title":"flush","content":"pub fn flush(file: Output, every interval: Int) -&gt; Output\n When outputting to a file, logger will dump messages in file every 5 seconds\n by defaults. `flush` allows to choose how long to wait before dumping\n messages in the file. Be careful, setting a too small interval could lead to\n performance issues, because BEAM will spend too much time in file writing.\nSynonyms:\npalabres/options.flush\npalabres/options flush","url":"palabres/options.html#flush"},{"doc":"palabres/options","title":"json","content":"pub fn json(options: Options, json: Bool) -&gt; Options\n Defaults to `False`. \\\n Activate or deactive JSON ouput. \\\n If activated, colored output is automatically deactivated.\nSynonyms:\npalabres/options.json\npalabres/options json","url":"palabres/options.html#json"},{"doc":"palabres/options","title":"level","content":"pub fn level(options: Options, level: Level) -&gt; Options\n Defaults to `level.Info`. Set the minimum desired log level.\nSynonyms:\npalabres/options.level\npalabres/options level","url":"palabres/options.html#level"},{"doc":"palabres/options","title":"output","content":"pub fn output(options: Options, to output: Output) -&gt; Options\n Defaults to `stdout`. Choose the desired output.\nSynonyms:\npalabres/options.output\npalabres/options output","url":"palabres/options.html#output"},{"doc":"palabres/options","title":"stdout","content":"pub fn stdout() -&gt; Output\n Creates the stdout output.\nSynonyms:\npalabres/options.stdout\npalabres/options stdout","url":"palabres/options.html#stdout"},{"doc":"palabres/options","title":"style_default_logger","content":"pub fn style_default_logger(\n  options: Options,\n  style_default: Bool,\n) -&gt; Options\n Defaults to `True`. \\\n Activate or deactivate styling from Palabres on default logger. \\\n Has no effect on JavaScript, since there&#39;s no default logger.\nSynonyms:\npalabres/options.style_default_logger\npalabres/options style_default_logger","url":"palabres/options.html#style_default_logger"},{"doc":"palabres/options","title":"palabres/options","content":" Options to configure Palabres at start.\n\n ```gleam\n import palabres\n import palabres/level\n import palabres/options\n\n pub fn configure_logger() {\n   options.defaults()\n   // Enables or disable colored output.\n   |&gt; options.color(True)\n   // Enables or disable JSON output. JSON output will never be colored.\n   |&gt; options.json(False)\n   // Set the minimum log level.\n   |&gt; options.level(level.Info)\n   // Output to a file instead of stdout.\n   |&gt; options.output(to: {\n     options.file(test_utils.log_file)\n     |&gt; options.flush(every: 5000)\n   })\n   // Applies or not palabres styling to default logger (on stdout).\n   |&gt; options.style_default_logger(True)\n   // Configure the logger.\n   |&gt; palabres.configure\n }\n ```","url":"palabres/options.html"},{"doc":"palabres","title":"Log","content":"pub opaque type Log\n Log instance, holding the structured data. Can be instanciated with\n corresponding &quot;level&quot; functions: [`emergency`](#emergency),\n [`alert`](#alert), [`critical`](#critical), [`error`](#error),\n [`warning`](#warning), [`notice`](#notice), [`info`](#info),\n [`debug`](#debug).\n\n \n pub fn log() {\n   palabres.info(&quot;This is a log&quot;)\n   |&gt; palabres.log\n }\n \n\nSynonyms:\npalabres.Log\npalabres Log","url":"palabres.html#Log"},{"doc":"palabres","title":"alert","content":"pub fn alert(message: String) -&gt; Log\n Creates an `Alert` `Log` instance. Should be used as a starting point\n to create a log.\n\n \n pub fn log() {\n   palabres.alert(&quot;Example message&quot;)\n   |&gt; palabres.log\n }\n \nSynonyms:\npalabres.alert\npalabres alert","url":"palabres.html#alert"},{"doc":"palabres","title":"at","content":"pub fn at(\n  log: Log,\n  module module: String,\n  function function: String,\n) -&gt; Log\n Debug information, used to easily pinpoint a location in your code. `at`\n should point to a module and a function, and will display in your logs\n a data looking like `at=module.function` with proper colored output if\n activated.\n\n \n pub fn log() {\n   palabres.info(&quot;Example message&quot;)\n   |&gt; palabres.at(&quot;my_logger&quot;, &quot;log&quot;)\n   |&gt; palabres.log\n   // Turns in:\n   //   level=info when=2024-12-15T15:59:17Z id=3a5c0fc2-5f74-4796-84df-cbfe4000eef6 at=my_logger.log Example message\n }\n \nSynonyms:\npalabres.at\npalabres at","url":"palabres.html#at"},{"doc":"palabres","title":"configure","content":"pub fn configure(options: Options) -&gt; Nil\n Configure Palabres logger. Because logger is a singleton, it only needs to be\n configured once at startup. Select your options, and run configurations, to\n get Palabres logger running. Each logger call will then go through Palabres\n on BEAM. On JavaScript, calling `palabres` functions are still required.\nSynonyms:\npalabres.configure\npalabres configure","url":"palabres.html#configure"},{"doc":"palabres","title":"critical","content":"pub fn critical(message: String) -&gt; Log\n Creates a `Critical` `Log` instance. Should be used as a starting point\n to create a log.\n\n \n pub fn log() {\n   palabres.critical(&quot;Example message&quot;)\n   |&gt; palabres.log\n }\n \nSynonyms:\npalabres.critical\npalabres critical","url":"palabres.html#critical"},{"doc":"palabres","title":"debug","content":"pub fn debug(message: String) -&gt; Log\n Creates a `Debug` `Log` instance. Should be used as a starting point\n to create a log.\n\n \n pub fn log() {\n   palabres.debug(&quot;Example message&quot;)\n   |&gt; palabres.log\n }\n \nSynonyms:\npalabres.debug\npalabres debug","url":"palabres.html#debug"},{"doc":"palabres","title":"emergency","content":"pub fn emergency(message: String) -&gt; Log\n Creates an `Emergency` `Log` instance. Should be used as a starting point\n to create a log.\n\n \n pub fn log() {\n   palabres.emergency(&quot;Example message&quot;)\n   |&gt; palabres.log\n }\n \nSynonyms:\npalabres.emergency\npalabres emergency","url":"palabres.html#emergency"},{"doc":"palabres","title":"error","content":"pub fn error(message: String) -&gt; Log\n Creates an `Error` `Log` instance. Should be used as a starting point\n to create a log.\n\n \n pub fn log() {\n   palabres.error(&quot;Example message&quot;)\n   |&gt; palabres.log\n }\n \nSynonyms:\npalabres.error\npalabres error","url":"palabres.html#error"},{"doc":"palabres","title":"float","content":"pub fn float(log: Log, key: String, value: Float) -&gt; Log\n Add a float field to your structured data.\n\n \n let field1 = 1.0\n palabres.info(&quot;Example&quot;)\n |&gt; palabres.float(&quot;field1&quot;, field1)\n |&gt; palabres.log\n \nSynonyms:\npalabres.float\npalabres float","url":"palabres.html#float"},{"doc":"palabres","title":"info","content":"pub fn info(message: String) -&gt; Log\n Creates an `Info` `Log` instance. Should be used as a starting point\n to create a log.\n\n \n pub fn log() {\n   palabres.info(&quot;Example message&quot;)\n   |&gt; palabres.log\n }\n \nSynonyms:\npalabres.info\npalabres info","url":"palabres.html#info"},{"doc":"palabres","title":"int","content":"pub fn int(log: Log, key: String, value: Int) -&gt; Log\n Add an int field to your structured data.\n\n \n let field1 = 1\n palabres.info(&quot;Example&quot;)\n |&gt; palabres.int(&quot;field1&quot;, field1)\n |&gt; palabres.log\n \nSynonyms:\npalabres.int\npalabres int","url":"palabres.html#int"},{"doc":"palabres","title":"log","content":"pub fn log(log_: Log) -&gt; Nil\n Run your log and make it display in your log output.\n\n \n palabres.info(&quot;Example&quot;)\n |&gt; palabres.log\n \nSynonyms:\npalabres.log\npalabres log","url":"palabres.html#log"},{"doc":"palabres","title":"log_alert","content":"pub fn log_alert(message: String) -&gt; Nil\n Log with message at level `Alert` directly. \\\n Avoid to write the full log pipeline when you just need to write a\n single message.\n\n \n palabres.log_alert(&quot;Example message&quot;)\n \nSynonyms:\npalabres.log_alert\npalabres log_alert","url":"palabres.html#log_alert"},{"doc":"palabres","title":"log_critical","content":"pub fn log_critical(message: String) -&gt; Nil\n Log with message at level `Critical` directly. \\\n Avoid to write the full log pipeline when you just need to write a\n single message.\n\n \n palabres.log_critical(&quot;Example message&quot;)\n \nSynonyms:\npalabres.log_critical\npalabres log_critical","url":"palabres.html#log_critical"},{"doc":"palabres","title":"log_debug","content":"pub fn log_debug(message: String) -&gt; Nil\n Log with message at level `Debug` directly. \\\n Avoid to write the full log pipeline when you just need to write a\n single message.\n\n \n palabres.log_debug(&quot;Example message&quot;)\n \nSynonyms:\npalabres.log_debug\npalabres log_debug","url":"palabres.html#log_debug"},{"doc":"palabres","title":"log_emergency","content":"pub fn log_emergency(message: String) -&gt; Nil\n Log with message at level `Emergency` directly. \\\n Avoid to write the full log pipeline when you just need to write a\n single message.\n\n \n palabres.log_emergency(&quot;Example message&quot;)\n \nSynonyms:\npalabres.log_emergency\npalabres log_emergency","url":"palabres.html#log_emergency"},{"doc":"palabres","title":"log_error","content":"pub fn log_error(message: String) -&gt; Nil\n Log with message at level `Error` directly. \\\n Avoid to write the full log pipeline when you just need to write a\n single message.\n\n \n palabres.log_error(&quot;Example message&quot;)\n \nSynonyms:\npalabres.log_error\npalabres log_error","url":"palabres.html#log_error"},{"doc":"palabres","title":"log_info","content":"pub fn log_info(message: String) -&gt; Nil\n Log with message at level `Info` directly. \\\n Avoid to write the full log pipeline when you just need to write a\n single message.\n\n \n palabres.log_info(&quot;Example message&quot;)\n \nSynonyms:\npalabres.log_info\npalabres log_info","url":"palabres.html#log_info"},{"doc":"palabres","title":"log_notice","content":"pub fn log_notice(message: String) -&gt; Nil\n Log with message at level `Notice` directly. \\\n Avoid to write the full log pipeline when you just need to write a\n single message.\n\n \n palabres.log_notice(&quot;Example message&quot;)\n \nSynonyms:\npalabres.log_notice\npalabres log_notice","url":"palabres.html#log_notice"},{"doc":"palabres","title":"log_request","content":"pub fn log_request(\n  req: Request(Connection),\n  handler: fn() -&gt; Response(Body),\n) -&gt; Response(Body)\n Provides a middleware to display every incoming request for a Wisp server.\\\n Use it in your router to log request with status code, path and method.\n\n \n pub fn router(req: wisp.Request, ctx: context) {\n   use &lt;- palabres.log_request(req)\n   route_request(req)\n }\n \nSynonyms:\npalabres.log_request\npalabres log_request","url":"palabres.html#log_request"},{"doc":"palabres","title":"log_warning","content":"pub fn log_warning(message: String) -&gt; Nil\n Log with message at level `Warning` directly. \\\n Avoid to write the full log pipeline when you just need to write a\n single message.\n\n \n palabres.log_warning(&quot;Example message&quot;)\n \nSynonyms:\npalabres.log_warning\npalabres log_warning","url":"palabres.html#log_warning"},{"doc":"palabres","title":"notice","content":"pub fn notice(message: String) -&gt; Log\n Creates a `Notice` `Log` instance. Should be used as a starting point\n to create a log.\n\n \n pub fn log() {\n   palabres.notice(&quot;Example message&quot;)\n   |&gt; palabres.log\n }\n \nSynonyms:\npalabres.notice\npalabres notice","url":"palabres.html#notice"},{"doc":"palabres","title":"nullable","content":"pub fn nullable(\n  log: Log,\n  key: String,\n  value: Option(a),\n  add: fn(Log, String, a) -&gt; Log,\n) -&gt; Log\n Add a potentially null value to your structured data.\n `None` will be converted to `null`, while `Some(x)` will be converted to `x`.\n\n \n let field1 = option.Some(1)\n palabres.info(&quot;Example&quot;)\n |&gt; palabres.nullable(&quot;field1&quot;, field1, palabres.int)\n |&gt; palabres.log\n \nSynonyms:\npalabres.nullable\npalabres nullable","url":"palabres.html#nullable"},{"doc":"palabres","title":"string","content":"pub fn string(log: Log, key: String, value: String) -&gt; Log\n Add a string field to your structured data.\n\n \n let field1 = 1.0\n palabres.info(&quot;Example&quot;)\n |&gt; palabres.string(&quot;field1&quot;, field1)\n |&gt; palabres.log\n \nSynonyms:\npalabres.string\npalabres string","url":"palabres.html#string"},{"doc":"palabres","title":"warning","content":"pub fn warning(message: String) -&gt; Log\n Creates a `Warning` `Log` instance. Should be used as a starting point\n to create a log.\n\n \n pub fn log() {\n   palabres.warning(&quot;Example message&quot;)\n   |&gt; palabres.log\n }\n \nSynonyms:\npalabres.warning\npalabres warning","url":"palabres.html#warning"},{"doc":"palabres","title":"palabres","content":" ### Overview\n\n Palabres is an opinionated logger, thought out to be compatible\n out-of-the-box with BEAM and every JavaScript runtimes, whether it&#39;s in\n browser or not, in Node or Deno, etc. In it&#39;s simplest form, Palabres will\n simply creates a logger configured according to your needs, and will take\n care of the rest. Palabres considers logs as structured logs, to help you\n add context to your logs, and help you in future debugging sessions.\n\n #### Structured logs\n\n Logs can simply be strings output to your standard output, and have various\n roles. Most of the time, it is used to help debugging, and to see what&#39;s\n happening in real time in production servers. However, you can also use\n logs to perform some analytics. Or maybe you want to track some user\n activities. That&#39;s where structured logs shine: instead of outputting\n simple strings, it&#39;s possible to output complex, rich data. To simplify that\n usage, Palabres helps by providing constructors functions. You can use\n `palabres.string`, `palabres.int` or `palabres.float` to add a field, with\n its name and a value. They will automatically be part of the resulting log.\n In Palabres, every log is not only a text message, but also context data\n that you&#39;re free to add to help in further usages. Those additionnal data\n are free, so it&#39;s up to you to determine how to use them efficiently!\n\n #### Handling logs\n\n Because logs are handled in multiple manners nowadays, Palabres provides two\n output formats: as string and as JSON. In the former format, every string\n will be formatted like query strings, but in a human readable way: no weird\n ampersand, no escaping. You can enjoy structured format while keeping it\n short, simple, and still easy to parse if needed. However, for processing\n logs, Palabres provides an easier JSON format. JSON formatting in logs allows\n to simply read and process them, and is widly implemented. DataDog, AWS\n CloudWatch, PaperTrail or NewRelic, all of them handle JSON logs without\n further configuration. Doing so also allows you to build on top of Palabres,\n and add specific structured fields required in your log processor.\n\n #### Default values\n\n Palabres imposes 4 standard data in every log: the level of the log, its\n timestamp, an ID in UUID format, and an arbitrary message string. You don&#39;t\n have anything to do to add timestamp, id and level, they will automatically\n be added to every log you create. They&#39;re all here to help you in future\n log processing sessions. In the worst case, they can be safely ignored. In\n the best case, they help you figure out what&#39;s happening, when an where.\n\n Arbitrary text messages are parts of log, and instead of putting them in a\n specific field, they&#39;re simply dumped as is in the string format, or under\n the `message` field in JSON.\n\n ### Usage Example\n\n ```gleam\n import palabres\n import palabres/options\n\n pub fn configure_logger() {\n   use json_output &lt;- result.try(is_json_output())\n   options.defaults()\n   |&gt; options.json(json_output)\n   |&gt; palabres.configure\n }\n\n pub fn log_message(message, user) {\n   palabres.info(message)\n   |&gt; palabres.string(&quot;node&quot;, get_node_info())\n   |&gt; palabres.string(&quot;user_id&quot;, user.id)\n   |&gt; palabres.int(&quot;user_age&quot;, user.age)\n   |&gt; palabres.log\n }\n\n fn is_json_output() {\n   use output &lt;- result.try(envoy.get(&quot;JSON_OUTPUT&quot;))\n   use &lt;- bool.guard(when: json_output != &quot;true&quot;, return: False)\n   True\n }\n ```\n\n ### How does it work?\n\n Behind the scenes, Palabres has two different behaviours, depending on your\n target. When targetting Erlang, Palabres will act as a `logger` layer, and\n will take care of the formatting, filtering, and helping to deal with\n `logger` for you. You don&#39;t need to dive in its interface, Palabres got you\n covered. You can use Palabres to create your logs, but nothing stops you to\n use something like `wisp.log_info` in your code. In that case, Palabres\n can still intervene and apply styling. That allow you to write simple\n logs functions, while still leveraging structured logs. Because Palabres\n relies on `logger`, you can rather easily interact with Palabres in Erlang,\n provided you know how to use `logger`.\n\n On JavaScript though, Palabres instanciate a full-fledged, custom logger.\n Because JavaScript does not have any logger concept in its root, Palabres\n provides a logger with similar abilities than `logger` on BEAM. As such,\n every logs _should go_ through the Palabres package, otherwise the logger\n won&#39;t be able to format them accordingly.","url":"palabres.html"}]);